====================
py-ldlm
====================

.. |ldlm_link| raw:: html

   <a href="http://github.com/imoore76/ldlm" target="_blank">LDLM</a>

.. image:: _static/logo.png
    :align: center
    :alt: ldlm logo

.. centered::
    version - |release|

.. centered::
    An |ldlm_link| client library providing Python sync and async clients.

Contents
----------

.. toctree::
    :maxdepth: 2

    overview
    ldlm
    contributing
    license


Disclaimer
--------------------

This project is not an official Google project. It is not supported by Google and Google specifically disclaims all warranties as to its quality, merchantability, or fitness for a particular purpose. 
